You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shale.apache.org by cr...@apache.org on 2006/09/03 06:58:27 UTC

svn commit: r439721 - in /shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test: core/systest/IntegrationTestCase.java dialog2/ dialog2/legacy/ dialog2/legacy/systest/ dialog2/legacy/systest/IntegrationTestCase.java

Author: craigmcc
Date: Sat Sep  2 21:58:26 2006
New Revision: 439721

URL: http://svn.apache.org/viewvc?rev=439721&view=rev
Log:
Correct the package name for the system integration tests test case,
set up a basic test to verify operation.

Added:
    shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/
    shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/legacy/
    shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/legacy/systest/
    shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/legacy/systest/IntegrationTestCase.java
      - copied, changed from r439660, shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/core/systest/IntegrationTestCase.java
Removed:
    shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/core/systest/IntegrationTestCase.java

Copied: shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/legacy/systest/IntegrationTestCase.java (from r439660, shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/core/systest/IntegrationTestCase.java)
URL: http://svn.apache.org/viewvc/shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/legacy/systest/IntegrationTestCase.java?p2=shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/legacy/systest/IntegrationTestCase.java&p1=shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/core/systest/IntegrationTestCase.java&r1=439660&r2=439721&rev=439721&view=diff
==============================================================================
--- shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/core/systest/IntegrationTestCase.java (original)
+++ shale/sandbox/shale-test-dialog2-legacy/src/test/java/org/apache/shale/examples/test/dialog2/legacy/systest/IntegrationTestCase.java Sat Sep  2 21:58:26 2006
@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 The Apache Software Foundation.
+ * Copyright 2006 The Apache Software Foundation.
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -12,11 +12,9 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
- * $Id$
  */
 
-package org.apache.shale.examples.test.core.systest;
+package org.apache.shale.examples.test.dialog2.legacy.systest;
 
 import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
 import com.gargoylesoftware.htmlunit.html.HtmlElement;
@@ -26,7 +24,7 @@
 import org.apache.shale.test.htmlunit.AbstractHtmlUnitTestCase;
 
 /**
  * <p>Integration tests for the Shale Tiger Extensions Library.</p>
  */
 public class IntegrationTestCase extends AbstractHtmlUnitTestCase {
     
@@ -87,12 +85,13 @@
     // Test /menu.jsp
     public void testMenu() throws Exception {
 
-        assertEquals("Shale Test App (Core Library)", title());
+        assertEquals("Shale Test App (Dialog2 Legacy Implementation)", title());
 
     }
 
 
     // Test /standard.jsp
+/*
     public void testStandard() throws Exception {
 
         HtmlElement element;
@@ -150,9 +149,11 @@
         assertEquals("true", element.asText());
 
     }
+*/
 
 
     // Test access /status.jsp
+/*
     public void testStatus() throws Exception {
 
         HtmlElement element;
@@ -175,6 +176,7 @@
                      element.asText());
 
     }
+*/
 
 
 }
@@ -26,7 +24,7 @@
 
 /**
- * <p>Integration tests for the Shale Tiger Extensions Library.</p>
+ * <p>Integration tests for the Shale Dialog2 Legacy Implementation.</p>
  */
 public class IntegrationTestCase extends AbstractHtmlUnitTestCase {